@@ -9,7 +9,6 @@ Implementation of HDPM with uncertainty in the words.
 
 import logging, numpy, numpy.random as R
 from numpy import log, exp
-from numpy.random import rand
 from scipy.stats import bernoulli, poisson
 from scipy.special import digamma, polygamma, gammaln
 from optparse import OptionGroup, OptionParser
@@ -256,6 +255,7 @@ def approx_log_a_plus_n(a, E, V):
 
 def sample_rho(G, average_n_g):
     "Sample random values of rho."
+    from numpy.random import rand
     return [rand(n_g) for n_g in poisson.rvs(average_n_g, size=G)]
 
 
@@ -398,6 +398,7 @@ class VariationalDistribution(object):
         """
         Initialise the variational distributions of a HDPM by sampling the generative model (ignoring the data).
         """
+        from numpy.random import rand
         
         self.q_gamma = GammaDist(self.data.options.a_gamma, self.data.options.b_gamma)
         "Variational distribution over gamma."
@@ -446,7 +447,7 @@ class VariationalDistribution(object):
             for i, (_, rhos) in enumerate(gene):
                 self.d[g][i] = numpy.zeros((len(rhos), self.K+1))
                 for j, rho in enumerate(rhos):
-                    if numpy.random.rand() < rho:
+                    if rand() < rho:
                         self.d[g][i][j,0] = 1.
                     else:
                         self.d[g][i][j,discrete_sample(t)+1] = 1.
